@@ -13,7 +13,7 @@ readFactivaHTML <- FunctionGenerator(function(elem, language, id) {
                      xml_text(xml_find_all(elem$content, ".//p[starts-with(@class, 'articleParagraph')]")))
 
         vars <- c("AN", "BY", "CO", "CY", "ED", "HD", "IN", "IPC", "IPD",
-                  "LA", "LP", "NS", "PD", "PUB", "RE", "SE", "SN", "TD", "WC")
+                  "LA", "LP", "NS", "PD", "PG", "PUB", "RE", "SE", "SN", "TD", "WC")
 
         # Remove trailing spaces when matching
         data <- as.character(table[match(vars, gsub("[^[A-Z]", "", table[,1])), 2])
@@ -39,18 +39,10 @@ readFactivaHTML <- FunctionGenerator(function(elem, language, id) {
         }
 
         data[["AN"]] <- gsub("Document ", "", data[["AN"]])
+        id <- if(!is.na(data[["AN"]])) data[["AN"]] else paste(sample(LETTERS, 10), collapse="")
 
         wc <- as.integer(regmatches(data[["WC"]], regexpr("^[[:digit:]]+", data[["WC"]])))[[1]]
 
-        # Extract useful information: origin, date, and code
-        m <- regmatches(data[["AN"]], regexec("^([A-Za-z]+)0*[1-9][0-9]([0-9][0-9][0-3][0-9][0-3][0-9])([A-Za-z0-9])",
-                                              data[["AN"]]))[[1]]
-        # If extraction failed for some reason, make sure we return a unique identifier
-        if(length(m) == 4)
-            id <- paste(toupper(m[2]), "-", m[3], "-", m[4], sep="")
-        else
-            id <- paste(sample(LETTERS, 10), collapse="")
-
         subject <- if(!is.na(data[["NS"]])) strsplit(data[["NS"]], "( \\| )")[[1]]
                    else character(0)
         # Remove leading code and invisible characters, esp. \n, before matching the pattern
@@ -103,6 +95,7 @@ readFactivaHTML <- FunctionGenerator(function(elem, language, id) {
         meta(doc, "industry") <- industry
         meta(doc, "infocode") <- infocode
         meta(doc, "infodesc") <- infodesc
+        meta(doc, "page") <- if(!is.na(data[["PG"]])) data[["PG"]] else character(0)
         meta(doc, "wordcount") <- wc
         meta(doc, "publisher") <- if(!is.na(data[["PUB"]])) data[["PUB"]] else character(0)
         meta(doc, "rights") <- if(!is.na(data[["CY"]])) data[["CY"]] else character(0)
